==> zio-aws-memorydb_3-5.17.155.1-sources.jar: zio/aws/memorydb/model/DeleteParameterGroupResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DeleteParameterGroupResponse(
    parameterGroup: Option[zio.aws.memorydb.model.ParameterGroup] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse = {
    import DeleteParameterGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse
      .builder()
      .optionallyWith(parameterGroup.map(value => value.buildAwsValue()))(
        _.parameterGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.DeleteParameterGroupResponse.ReadOnly =
    zio.aws.memorydb.model.DeleteParameterGroupResponse.wrap(buildAwsValue())
}
object DeleteParameterGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.DeleteParameterGroupResponse =
      zio.aws.memorydb.model.DeleteParameterGroupResponse(
        parameterGroup.map(value => value.asEditable)
      )
    def parameterGroup: Option[zio.aws.memorydb.model.ParameterGroup.ReadOnly]
    def getParameterGroup
        : ZIO[Any, AwsError, zio.aws.memorydb.model.ParameterGroup.ReadOnly] =
      AwsError.unwrapOptionField("parameterGroup", parameterGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse
  ) extends zio.aws.memorydb.model.DeleteParameterGroupResponse.ReadOnly {
    override val parameterGroup
        : Option[zio.aws.memorydb.model.ParameterGroup.ReadOnly] = scala
      .Option(impl.parameterGroup())
      .map(value => zio.aws.memorydb.model.ParameterGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse
  ): zio.aws.memorydb.model.DeleteParameterGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-memorydb_3-6.20.78.2-sources.jar: zio/aws/memorydb/model/DeleteParameterGroupResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DeleteParameterGroupResponse(
    parameterGroup: Optional[zio.aws.memorydb.model.ParameterGroup] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse = {
    import DeleteParameterGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse
      .builder()
      .optionallyWith(parameterGroup.map(value => value.buildAwsValue()))(
        _.parameterGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.DeleteParameterGroupResponse.ReadOnly =
    zio.aws.memorydb.model.DeleteParameterGroupResponse.wrap(buildAwsValue())
}
object DeleteParameterGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.DeleteParameterGroupResponse =
      zio.aws.memorydb.model.DeleteParameterGroupResponse(
        parameterGroup.map(value => value.asEditable)
      )
    def parameterGroup: Optional[zio.aws.memorydb.model.ParameterGroup.ReadOnly]
    def getParameterGroup
        : ZIO[Any, AwsError, zio.aws.memorydb.model.ParameterGroup.ReadOnly] =
      AwsError.unwrapOptionField("parameterGroup", parameterGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse
  ) extends zio.aws.memorydb.model.DeleteParameterGroupResponse.ReadOnly {
    override val parameterGroup
        : Optional[zio.aws.memorydb.model.ParameterGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameterGroup())
        .map(value => zio.aws.memorydb.model.ParameterGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteParameterGroupResponse
  ): zio.aws.memorydb.model.DeleteParameterGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}
